@@ -1,13 +1,11 @@
 ################################################################################
-#' @title Bandwidth Selection for Manipulation Testing Using Local-Polynomial Density Estimation.
+#' @title Bandwidth Selection for Manipulation Testing Using Local Polynomial Density Estimation
 #'
 #' @description \code{rdbwdensity} implements several data-driven bandwidth selection methods
-#'   useful to construct manipulation testing procedures using the local polynomial
-#'   density estimators proposed in \href{http://www-personal.umich.edu/~cattaneo/papers/Cattaneo-Jansson-Ma_2017_LocPolDensity.pdf}{Cattaneo, Jansson and Ma (2017a)}.
+#'   for the manipulation testing procedure of Cattaneo, Jansson and Ma (2019).
 #'
 #' Companion command: \code{\link{rddensity}} for density discontinuity (manipulation)
-#'   testing. A companion \code{Stata} package is described in \href{http://www-personal.umich.edu/~cattaneo/papers/Cattaneo-Jansson-Ma_2017_Stata.pdf}{Cattaneo,
-#'   Jansson and Ma (2017b)}.
+#'   testing. A companion \code{Stata} package is described in Cattaneo, Jansson and Ma (2018).
 #'
 #' Related Stata and R packages useful for inference in regression discontinuity (RD)
 #'   designs are described at \url{https://sites.google.com/site/rdpackages}.
@@ -38,21 +36,24 @@
 #' \item{X_max}{Largest observations to the left and right of the cutoff.}
 #'
 #' @references
-#' M. D. Cattaneo, M. Jansson and X. Ma. (2017a).  \href{http://www-personal.umich.edu/~cattaneo/papers/Cattaneo-Jansson-Ma_2017_LocPolDensity.pdf}{Simple Local Polynomial Density Estimators}. Working Paper, University of Michigan.
+#' M.D. Cattaneo, M. Jansson and X. Ma. (2018). \href{https://sites.google.com/site/rdpackages/rddensity/Cattaneo-Jansson-Ma_2018_Stata.pdf}{Manipulation Testing based on Density Discontinuity}.  \emph{Stata Journal} 18(1): 234-261.
 #'
-#' M. D. Cattaneo, M. Jansson and X. Ma. (2017b). \href{http://www-personal.umich.edu/~cattaneo/papers/Cattaneo-Jansson-Ma_2017_Stata.pdf}{rddensity: Manipulation Testing based on Density Discontinuity}. Working Paper, University of Michigan.
+#' M.D. Cattaneo, M. Jansson and X. Ma. (2019).  \href{https://arxiv.org/abs/1811.11512}{Simple Local Polynomial Density Estimators}. \emph{Journal of the American Statistical Association}, forthcoming.
 #'
 #' @author
-#' Matias D. Cattaneo, University of Michigan.  \email{cattaneo@umich.edu}.
+#' Matias D. Cattaneo, Princeton University  \email{cattaneo@princeton.edu}.
 #'
-#' Michael Jansson, University of California, Berkeley.  \email{mjansson@econ.berkeley.edu}.
+#' Michael Jansson, University of California Berkeley.  \email{mjansson@econ.berkeley.edu}.
 #'
-#' Xinwei Ma (maintainer), University of Michigan. \email{xinweima@umich.edu}.
+#' Xinwei Ma (maintainer), University of California San Diego. \email{x1ma@ucsd.edu}.
 #'
 #' @seealso \code{\link{rddensity}}
 #'
 #' @examples
+#' # Generate a random sample
 #' set.seed(42); x <- rnorm(2000, mean = -0.5)
+#'
+#' # Construct bandwidth
 #' summary(rdbwdensity(X = x, vce="jackknife"))
 #'
 #' @export
@@ -69,6 +70,15 @@ rdbwdensity <- function(X, c=0, p=2, kernel="", fitselect="", vce="") {
   vce <- tolower(vce)
   # end of default values
 
+  ################################################################################
+  # missing value handling
+  ################################################################################
+  X <- as.vector(X)
+  if (any(is.na(X))) {
+    warning(paste(sum(is.na(X)), " missing ", switch((sum(is.na(X))>1)+1, "observation is", "observations are"), " ignored.\n", sep=""))
+    X <- X[!is.na(X)]
+  }
+
   ################################################################################
   # sample sizes
   ################################################################################
@@ -195,9 +205,3 @@ print.CJMrdbwdensity <- function(x, ...) {
   cat("Model:\ ", x$opt$fitselect, ". ", "Kernel: ", x$opt$kernel, ". ", "VCE: ", x$opt$vce, sep="")
 }
 
-
-
-
-
-
-
